#
# spec file for package iucode-tool
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           iucode-tool
Version:        2.3.1
Release:        bp160.1.5
Summary:        A program to manipulate Intel microcode update collections
License:        GPL-2.0-only
Group:          System/Boot
URL:            https://gitlab.com/iucode-tool/iucode-tool
Source:         %{name}-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
ExclusiveArch:  %{ix86} x86_64

%description
iucode_tool is a program to manipulate microcode update collections for
Intel i686 and X86-64 system processors, and prepare them for use by the
Linux kernel.

%prep
%setup -q

%build
autoreconf -fiv
%configure
make %{?_smp_mflags}

%install
%make_install

%files
%license COPYING
%doc README
%{_sbindir}/iucode_tool
%{_mandir}/man8/iucode_tool.8%{ext_man}

%changelog
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid use of ®/™ signs in specfiles as per
  https://en.opensuse.org/openSUSE:Package_description_guidelines#Trademarks_in_Summary_or_Description
  (section created by user hennevogel(SUSE) on 2010-05-07)
* Thu Mar  8 2018 mpluskal@suse.com
- Update to version 2.3.1:
  * Ready for release: v2.3.1
  * iucode_tool: fix filter by revision parser on ILP32
* Fri Feb  2 2018 mpluskal@suse.com
- Update to version 2.3:
  * Ready for release: v2.3
  * update copyright dates to 2018
  * iucode_tool(8): document changes to ucode filtering
  * iucode_tool: support selecting by ucode revision
  * iucode_tool: add function to parse signed 32-bit integers
  * iucode_tool: optimize detection of base10 numeric names
  * iucode_tool: better handle offline/non-continuous topology
  * iucode_tool(8): document changes to --scan-system
  * iucode_tool: select scan-system strategy change at runtime
  * gitignore: rearrange, and ignore backup and vim swap files
  * iucode_tool: move scan_system_processor() one layer down
  * iucode_tool: do not scan-system while parsing
  * iucode_tool: add two command-line parser helpers
  * intel_microcode.h: document intel_ucode_status_t sources
* Thu Oct 19 2017 mpluskal@suse.com
- Update to version 2.2:
  * configure.ac: whitespace fixes
  * configure: minor cosmetic fixes
  * configure: default build to hardened -O3 PIE with lots of warnings
  * configure.ac: add --enable-extend-flags to change default build flags
  * README: add an example of microcode with multiple sigs
  * iucode_tool: ensure printf %%x args are unsigned
  * intel_microcode: declare intel_ucode_errstr() as const
  * iucode_tool: use fprintf(stdout) instead of printf()
  * intel_microcode: do not request inlining for is_zero_checksum()
  * configure.ac: support libargp as an alternative to glibc argp
  * iucode_tool: rename and document some xx_xtsdeduplist* functions
  * iucode_tool: fix microcode count when selecting extended signatures
  * intel_microcode: fast-track intel_ucode_compare(a, a)
  * configure.ac: fix handling of --without-foo/--disable-bar
  * README: update for mixed dat and bin Intel releases
  * Ready for release: v2.2
* Fri Mar 24 2017 mpluskal@suse.com
- Update to version 2.1.2:
  * iucode_tool: skip small files as if empty in the -tr loader
  * iucode_tool: silence a harmless -Wmissing-field-initializers warning
  * iucode_tool: compare payloads of similar (not just duplicate) MCUs
  * intel-microcode: validade xx_intel_ucode_check_uc() parameters
  * Ready for release: v2.1.2
* Sat Jan 14 2017 mpluskal@suse.com
- Update to version 2.1.1 (boo#1019946):
  * intel_microcode: fix heap buffer overflow on -tr loader
  * intel_microcode, iucode_tool: track buffer sizes when iterating
  * intel_microcode: forbid unknown buffer sizes in intel_ucode_check_microcode()
  * intel_microcode, iucode_tool: no more magic 1024 constants
  * intel_microcode: harden intel_ucode_scan_for_microcode()
  * intel_microcode, iucode_tool: enhance microcode scan API
  * spelling fixes to comments, messages and docs
  * update copyright dates to 2017
  * Ready for release: v2.1.1
  * ChangeLog, NEWS: add CVE-2017-0357
* Thu Nov 24 2016 mpluskal@suse.com
- Update to version 2.1:
  * iucode_tool: prepare for early-initramfs size minimization
  * iucode_tool: add command line option to minimize early initramfs size
  * iucode_tool(8): document --mini-earlyfw and --normal-earlyfw
  * iucode_tool: cosmetic error path cleanup for write_cpio_header()
  * iucode_tool: alternative bug-workaround for the early initramfs
  * intel_microcode: constify and restyle function prototypes
  * iucode_tool: constify function paramenters
  * Makefile.am: ship CONTRIBUTING in the tarball
  * Ready for release: v2.1
* Mon Aug 29 2016 mpluskal@suse.com
- Update to version 1.6.1:
  * iucode_tool: fix another downgrade+loose date filter corner case
  * iucode_tool: use pfm for pf_mask in structures
  * iucode_tool: warn of shadowed microcode in downgrade mode
  * iucode_tool(8): document warning when downgrade mode fails
  * iucode_tool: fix failsafe for --enable-cpuid-device
  * Ready for release: v1.6
  * iucode_tool: constify argp parser information
  * iucode_tool(8): update Linux notes for up to v4.6
  * iucode_tool(8): minor fix to a comment
  * iucode_tool: don't close input files twice
  * iucode_tool: stop allocating twice the required memory for a bundle
  * iucode_tool: append microcode bundles to linked list in O(1)
  * Ready for release: v1.6.1
* Tue Sep 22 2015 fvogt@suse.com
- Initial commit
